/*
 * Copyright 2011 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.gradle.api.internal.artifacts.ivyservice.ivyresolve;

import org.gradle.api.internal.artifacts.ivyservice.DependencyToModuleVersionResolver;
import org.gradle.api.internal.artifacts.ivyservice.ivyresolve.strategy.LatestStrategy;
import org.gradle.api.internal.artifacts.ivyservice.ivyresolve.strategy.VersionMatcher;

class DefaultIvyAdapter implements IvyAdapter {
    private final VersionMatcher versionMatcher;
    private final LatestStrategy latestStrategy;
    private final DependencyToModuleVersionResolver userResolver;

    public DefaultIvyAdapter(VersionMatcher versionMatcher, LatestStrategy latestStrategy, DependencyToModuleVersionResolver userResolverChain) {
        this.versionMatcher = versionMatcher;
        this.latestStrategy = latestStrategy;
        userResolver = userResolverChain;
    }

    public LatestStrategy getLatestStrategy() {
        return latestStrategy;
    }

    public VersionMatcher getVersionMatcher() {
        return versionMatcher;
    }

    public DependencyToModuleVersionResolver getDependencyToModuleResolver() {
        return userResolver;
    }
}
